/*
 * Copyright (C) 2012 Frederic Markert
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

const Lang = imports.lang;
const Main = imports.ui.main;
const PanelMenu = imports.ui.panelMenu;
const Shell = imports.gi.Shell;
const St = imports.gi.St;
const Mainloop = imports.mainloop;

let display = null;
let timeout = null;

function Display() {
	this._init.apply(this, arguments);
}

Display.prototype = {
	__proto__: PanelMenu.Button.prototype,

	_init: function() {
		PanelMenu.Button.prototype._init.call(this, 0.0, "Uptime");

		this.actor.visible = true;
		this._countLabel = new St.Label();
		this.actor.add_actor(this._countLabel);
		this.update();
		
		timeout = Mainloop.timeout_add_seconds(30, Lang.bind(this, this.update));
	},

        update: function() {
		let timestamps = Shell.get_file_contents_utf8_sync('/proc/uptime').split(" ");
		let minutes = Math.floor(timestamps[0] / 60 % 60);
		if(minutes < 10) {
			minutes = "0" + minutes;
		}
		let hours = Math.floor(timestamps[0] / 3600);
		this._countLabel.set_text("" + hours + ":" + minutes);
		return true;
        }
}

function init() {
	display = new Display();
}

function enable() {
	Main.panel.addToStatusArea('Uptime', display, 0);
}

function disable() {
	Mainloop.source_remove(timeout);
	timeout = null;
	display.destroy();
	display = null;
}
